import clsx from 'clsx';
import { useEffect } from 'react';
import { Unity, useUnityContext } from 'react-unity-webgl';
import zmpSdk from 'zmp-sdk';

export const UnityGame = () => {
  const gameLink = import.meta.env.VITE_GAME_LINK;
  const { unityProvider, isLoaded, loadingProgression, UNSAFE__unityInstance } = useUnityContext({
    loaderUrl: `${gameLink}/Build/Build.loader.js`,
    dataUrl: `${gameLink}/Build/Build.data.unityweb`,
    frameworkUrl: `${gameLink}/Build/Build.framework.js.unityweb`,
    codeUrl: `${gameLink}/Build/Build.wasm.unityweb`,
  });

  useEffect(() => {
    window.ZaloMiniAppSDK = zmpSdk;
    window.unityInstance = UNSAFE__unityInstance;
  }, [UNSAFE__unityInstance]);

  return (
    <>
      {!isLoaded && (
        <div className={'h-full w-full items-center justify-center text-center'}>
          Loading {loadingProgression * 100 + 10}%
        </div>
      )}
      <Unity
        id='unity-canvas'
        unityProvider={unityProvider}
        className={clsx('h-full w-full', !isLoaded && 'hidden')}
        devicePixelRatio={window.devicePixelRatio}
      />
    </>
  );
};
